@@ -1,4 +1,4 @@
-"med" <-
+med <-
 function(x) {
 y <- quantile(x, .5, type=3)
 return(y[[1]])
